/**
 * Accessibar - options.js
 *
 * This file provides functionality for the options dialog whose interface
 * is described in optionsDialog.xul; and the option frames whose interfaces
 * are described in optionsKeyboard.xul and optionsReader.xul.
 *
 * @author Edan Kemelman <edankeme@yahoo.com>
 * @version 0.7.6
 */

function xsiLoadHelp(url) {
    window.opener.getBrowser().selectedTab = window.opener.getBrowser().addTab(url);
}


/**
*  optionsGeneral should not display ZoomIn/ZoomOut button config for FF versions below 3.0
*/
function hideZoomFromOlderFF() {
    var prefs = Components.classes["@mozilla.org/preferences-service;1"]
    .getService(Components.interfaces.nsIPrefService).getBranch("");
    var ffVer = prefs.getCharPref("extensions.lastAppVersion");

    // Get the main version number as an integer
    var verInt = parseInt(ffVer.charAt(0));

    // Lesser than 3.0 - hide buttons in General Options menu
    if (verInt < 3) {
        var zoomInBtn = window.document.getElementById("accessibar-btn-zoomin");
        var zoomOutBtn = window.document.getElementById("accessibar-btn-zoomout");
        zoomInBtn.collapsed = true;
        zoomOutBtn.collapsed = true;
    }

}

/**
 * Restores voice settings to default values.
 */
function xsiRestoreVoiceDefaults() {
    var prefs = Components.classes["@mozilla.org/preferences-service;1"]
    .getService(Components.interfaces.nsIPrefService).getBranch("");
    var defs = Components.classes["@mozilla.org/preferences-service;1"]
    .getService(Components.interfaces.nsIPrefService).getDefaultBranch("");
    
    prefs.setCharPref("accessibar.TextToSpeech.voice", defs.getCharPref("accessibar.TextToSpeech.voice"));    
    prefs.setIntPref("accessibar.TextToSpeech.volume", defs.getIntPref("accessibar.TextToSpeech.volume"));
    prefs.setIntPref("accessibar.TextToSpeech.speed", defs.getIntPref("accessibar.TextToSpeech.speed"));
    prefs.setIntPref("accessibar.TextToSpeech.pitch", defs.getIntPref("accessibar.TextToSpeech.pitch"));   
    prefs.setIntPref("accessibar.TextToSpeech.range", defs.getIntPref("accessibar.TextToSpeech.range"));
}

function xsiToggleTbBtn(btnID) {
    var tbBtn = window.opener.document.getElementById(btnID);
    
    tbBtn.collapsed = !tbBtn.collapsed;
}

function xsiUpdateDisplay(value) {
    var toolbar = window.opener.document.getElementById("accessibar");
    
    if(!toolbar || !window.toolbar.visible)
        return;
    
    toolbar.setAttribute("mode", value);
}

// Apply changes made in General Options to enhanced Focus indicator
function xsiUpdatePrefStyles() {
    var prefs = Components.classes["@mozilla.org/preferences-service;1"]
    .getService(Components.interfaces.nsIPrefService).getBranch("");
    
    if (!prefs.getBoolPref("accessibar.focus.enhanceindicator")) 
        return;
    
    window.opener.xsiApplyPrefStyles(true);
}

// On/Off for Preference styles (focus inicator and dashed underline)
function xsiPrefStyleSwitch(id, isOn) {
    
    // Turn off:
    if ( !isOn ) {
        if (id == "accessibar.focus.enhanceindicator")
            window.opener.xsiRemovePrefStyle("accessibar-pref-focus");
        if (id == "accessibar.links.dash_underline_visited")
            window.opener.xsiRemovePrefStyle("accessibar-pref-vlnk-dashed");    
    }
    // Turn on: we gotta add the style to the active styles array and then apply...
    else { 
        if (id == "accessibar.focus.enhanceindicator")
            window.opener.xsiAddActiveStyle("accessibar-pref-focus");
        if (id == "accessibar.links.dash_underline_visited") 
            window.opener.xsiAddActiveStyle("accessibar-pref-vlnk-dashed");
        
        window.opener.xsiApplyPrefStyles(true);
    }
}





